[gnumeric] clarify the meaning of the percentage option in the autofilter
- From: Andreas J. Guelzow <guelzow src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gnumeric] clarify the meaning of the percentage option in the autofilter
- Date: Mon, 11 Apr 2011 01:12:38 +0000 (UTC)
commit 036deb96b63b2a9561585f47812d17b0569c6c8d
Author: Andreas J Guelzow <aguelzow pyrshep ca>
Date: Sun Apr 10 19:12:10 2011 -0600
clarify the meaning of the percentage option in the autofilter
2011-04-10 Andreas J. Guelzow <aguelzow pyrshep ca>
* dialog-autofilter.c (cb_top10_count_changed): clarify the meaning of the
percentage option
src/dialogs/ChangeLog | 5 +++++
src/dialogs/dialog-autofilter.c | 12 ++++++------
2 files changed, 11 insertions(+), 6 deletions(-)
---
diff --git a/src/dialogs/ChangeLog b/src/dialogs/ChangeLog
index 16afb03..f6dd0e5 100644
--- a/src/dialogs/ChangeLog
+++ b/src/dialogs/ChangeLog
@@ -1,5 +1,10 @@
2011-04-10 Andreas J. Guelzow <aguelzow pyrshep ca>
+ * dialog-autofilter.c (cb_top10_count_changed): clarify the meaning of the
+ percentage option
+
+2011-04-10 Andreas J. Guelzow <aguelzow pyrshep ca>
+
* autofilter-top10.ui: redesign
* dialog-autofilter.c (type_group): new
(autofilter_get_type): new
diff --git a/src/dialogs/dialog-autofilter.c b/src/dialogs/dialog-autofilter.c
index e431f5f..de51cc3 100644
--- a/src/dialogs/dialog-autofilter.c
+++ b/src/dialogs/dialog-autofilter.c
@@ -217,21 +217,21 @@ cb_top10_count_changed (GtkSpinButton *button,
val = 100;
w = go_gtk_builder_get_widget (state->gui, type_group[2]);
/* xgettext : %d gives the percentage of items in the autofilter. */
/* This is input to ngettext. */
label = g_strdup_printf
- (ngettext ("Show the largest %3d%% of the items",
- "Show the largest %3d%% of the items", val),
+ (ngettext ("Show the items in the top %3d%% of the data range",
+ "Show the items in the top %3d%% of the data range", val),
val);
gtk_button_set_label (GTK_BUTTON (w),label);
g_free(label);
w = go_gtk_builder_get_widget (state->gui, type_group[3]);
/* xgettext : %d gives the percentage of items in the autofilter. */
/* This is input to ngettext. */
label = g_strdup_printf
- (ngettext ("Show the smallest %3d%% of the items",
- "Show the smallest %3d%% of the items", val),
+ (ngettext ("Show the items in the bottom %3d%% of the data range",
+ "Show the items in the bottom %3d%% of the data range", val),
val);
gtk_button_set_label (GTK_BUTTON (w),label);
g_free(label);
@@ -217,21 +217,21 @@ cb_top10_count_changed (GtkSpinButton *button,
val = 100;
w = go_gtk_builder_get_widget (state->gui, type_group[2]);
- /* xgettext : %d gives the percentage of items in the autofilter. */
+ /* xgettext : %d gives the percentage of the data range in the autofilter. */
/* This is input to ngettext. */
label = g_strdup_printf
@@ -217,21 +217,21 @@ cb_top10_count_changed (GtkSpinButton *button,
g_free(label);
w = go_gtk_builder_get_widget (state->gui, type_group[3]);
- /* xgettext : %d gives the percentage of items in the autofilter. */
+ /* xgettext : %d gives the percentage of the data range in the autofilter. */
/* This is input to ngettext. */
label = g_strdup_printf
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]